@@ -39,29 +39,45 @@
  * binary/load-time compatible, increment MAJOR version
  *
  *
+ * 6.1 (unreleased):
+ *	http_CollectHdrSep added
+ * 6.0 (2017-03-15):
+ *	VRT_hit_for_pass added
+ *	VRT_ipcmp added
+ *	VRT_Vmod_Init signature changed
+ *	VRT_vcl_lookup removed
+ *	VRT_vcl_get added
+ *	VRT_vcl_rel added
+ *	VRT_fail added
+ *	WS_Reset and WS_Snapshot signatures changed
+ *	WS_Front added
+ *	WS_ReserveLumps added
+ *	WS_Inside added
+ *	WS_Assert_Allocated added
  * 5.0:
  *	Varnish 5.0 release "better safe than sorry" bump
  * 4.0:
  *	VCL_BYTES changed to long long
+ *	VRT_CacheReqBody changed signature
  * 3.2:
  *	vrt_backend grew .proxy_header field
  *	vrt_ctx grew .sp field.
- *
- * older version:
- * Bump VRT_MINOR_VERSION due to:
- * - VCL_ACL type added
- * Bump VRT_MAJOR_VERSION due to:
- * - VRT_CacheReqBody changed signature
- *
+ *	vrt_acl type added
  */
 
-#define VRT_MAJOR_VERSION	5U
+#define VRT_MAJOR_VERSION	6U
 
 #define VRT_MINOR_VERSION	0U
 
 
 /***********************************************************************/
 
+#ifdef __v_printflike
+#  define __vrt_printflike(a,b) __v_printflike(a,b)
+#else
+#  define __vrt_printflike(a,b)
+#endif
+
 struct VCL_conf;
 struct vrt_acl;
 struct busyobj;
@@ -287,17 +303,20 @@ void VRT_purge(VRT_CTX, double ttl, double grace, double keep);
 
 void VRT_count(VRT_CTX, unsigned);
 void VRT_synth(VRT_CTX, unsigned, const char *);
+void VRT_hit_for_pass(VRT_CTX, VCL_DURATION);
 
 struct http *VRT_selecthttp(VRT_CTX, enum gethdr_e);
 const char *VRT_GetHdr(VRT_CTX, const struct gethdr_s *);
 void VRT_SetHdr(VRT_CTX, const struct gethdr_s *, const char *, ...);
 void VRT_handling(VRT_CTX, unsigned hand);
+void VRT_fail(VRT_CTX, const char *fmt, ...) __vrt_printflike(2,3);
 
 void VRT_hashdata(VRT_CTX, const char *str, ...);
 
 /* Simple stuff */
 int VRT_strcmp(const char *s1, const char *s2);
 void VRT_memmove(void *dst, const void *src, unsigned len);
+int VRT_ipcmp(const struct suckaddr *sua1, const struct suckaddr *sua2);
 
 void VRT_Rollback(VRT_CTX, const struct http *);
 
@@ -312,12 +331,13 @@ void VRT_delete_backend(VRT_CTX, struct director **);
 int VRT_VSA_GetPtr(const struct suckaddr *sua, const unsigned char ** dst);
 
 /* VMOD/Modules related */
-int VRT_Vmod_Init(struct vmod **hdl, void *ptr, int len, const char *nm,
-    const char *path, const char *file_id, VRT_CTX);
+int VRT_Vmod_Init(VRT_CTX, struct vmod **hdl, void *ptr, int len,
+    const char *nm, const char *path, const char *file_id, const char *backup);
 void VRT_Vmod_Fini(struct vmod **hdl);
 
 /* VCL program related */
-VCL_VCL VRT_vcl_lookup(const char *);
+VCL_VCL VRT_vcl_get(VRT_CTX, const char *);
+void VRT_vcl_rel(VRT_CTX, VCL_VCL);
 void VRT_vcl_select(VRT_CTX, VCL_VCL);
 
 struct vmod_priv;
